@@ -1,4 +1,4 @@
-/* $Id: display.cpp 16023 2007-02-23 17:17:44Z mordante $ */
+/* $Id: display.cpp 16280 2007-03-18 15:42:04Z mordante $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -90,7 +90,7 @@ display::display(unit_map& units, CVideo& video, const gamemap& map,
 	turbo_(false), grid_(false), sidebarScaling_(1.0),
 	theme_(theme_cfg,screen_area()), builder_(cfg, level, map),
 	first_turn_(true), in_game_(false), map_labels_(*this,map),
-	tod_hex_mask1(NULL), tod_hex_mask2(NULL),
+	tod_hex_mask1(NULL), tod_hex_mask2(NULL), reach_map_changed_(true),
 	diagnostic_label_(0), fps_handle_(0)
 {
 	if(non_interactive()) {
