@@ -22,6 +22,7 @@
 #include "../image.hpp"
 #include "../language.hpp"
 #include "../map.hpp"
+#include "../minimap.hpp"
 #include "../preferences.hpp"
 #include "../random.hpp"
 #include "../team.hpp"
@@ -93,7 +94,7 @@ int main(int argc, char** argv)
 			++arg;
 			choosen_bpp = lexical_cast_default<int>(argv[arg]);
 		}
-			
+
 		else if(val == "--resolution" || val == "-r") {
 			if(arg+1 != argc) {
 				++arg;
@@ -164,7 +165,7 @@ int main(int argc, char** argv)
 	image::set_wm_icon();
 	int video_flags = preferences::fullscreen() ? FULL_SCREEN : 0;
 	std::pair<int,int> resolution = preferences::resolution();
-	
+
 	std::cerr << "checking mode possible...\n";
 	const int default_bpp = 24;
 	int bpp = default_bpp;
@@ -211,7 +212,7 @@ int main(int argc, char** argv)
 	} else {
 		bpp = choosen_bpp;
 	}
-	
+
 	std::cerr << "setting mode to " << resolution.first << "x" << resolution.second << "\n";
 	const int res = video.setMode(resolution.first,resolution.second,bpp,video_flags);
 	video.setBpp(bpp);
@@ -235,12 +236,13 @@ int main(int argc, char** argv)
 	//Set the locale first, then read the configuration, or else WML
 	//strings are not correctly translated. Does this work on on the win32
 	//platform?
+	load_language_list();
 	const bool lang_res = ::set_language(get_locale());
 	if(!lang_res) {
 		std::cerr << "No translation for locale '" << get_locale().language
 		          << "', default to system locale\n";
 
-		const bool lang_res = ::set_language(known_languages[0]);
+		const bool lang_res = ::set_language(get_languages()[0]);
 		if(!lang_res) {
 			std::cerr << "Language data not found\n";
 		}
@@ -281,7 +283,7 @@ int main(int argc, char** argv)
 	}
 
 	std::cerr << "entering while...\n";
-	std::map<gamemap::location,unit> units;
+	unit_map units;
 	events::event_context ec;
 	while (! done) {
 		try {
@@ -304,7 +306,7 @@ int main(int argc, char** argv)
 		catch (gamemap::incorrect_format_exception) {
 			std::cerr << "The map is not in a correct format, sorry." << std::endl;
 			return 1;
-		} catch (CVideo::quit& e) {
+		} catch (CVideo::quit&) {
 			return 0;
 		}
 	}
