@@ -1,4 +1,4 @@
-/* $Id: mapgen_dialog.cpp 7533 2005-07-20 08:22:37Z ott $ */
+/* $Id: mapgen_dialog.cpp 11647 2006-05-26 01:03:08Z rusty $ */
 /*
    Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -13,13 +13,15 @@
 
 #include "global.hpp"
 
+#define GETTEXT_DOMAIN "wesnoth-lib"
+
 #include "mapgen_dialog.hpp"
 
 #include "display.hpp"
 #include "events.hpp"
-#include "font.hpp"
 #include "gettext.hpp"
 #include "mapgen.hpp"
+#include "marked-up_text.hpp"
 #include "show_dialog.hpp"
 #include "util.hpp"
 #include "video.hpp"
@@ -69,6 +71,10 @@ default_map_generator::default_map_generator(const config* cfg)
 		const int nplayers = ::atoi((*cfg)["players"].c_str());
 		if(nplayers > 0)
 			nplayers_ = nplayers;
+
+		const int island_size = ::atoi((*cfg)["island_size"].c_str());
+		if(island_size > 0)
+			island_size_ = island_size;
 	}
 }
 
@@ -277,7 +283,7 @@ void default_map_generator::user_config(display& disp)
 		update_rect(xpos,ypos,width,height);
 
 		disp.update_display();
-		SDL_Delay(10);
+		disp.delay(10);
 		events::pump();
 	}
 
@@ -291,7 +297,7 @@ std::string default_map_generator::create_map(const std::vector<std::string>& ar
 	return generate_map(args);
 }
 
-std::string default_map_generator::generate_map(const std::vector<std::string>& args, std::map<gamemap::location,std::string>* labels)
+std::string default_map_generator::generate_map(const std::vector<std::string>& /*args*/, std::map<gamemap::location,std::string>* labels)
 {
 	// the random generator thinks odd widths are nasty, so make them even
 	if (is_odd(width_))
@@ -341,7 +347,7 @@ config default_map_generator::create_scenario(const std::vector<std::string>& ar
 	std::cerr << "done generating map..\n";
 
 	for(std::map<gamemap::location,std::string>::const_iterator i = labels.begin(); i != labels.end(); ++i) {
-		if(i->first.x >= 0 && i->first.y >= 0 && i->first.x < width_ && i->first.y < height_) {
+		if(i->first.x >= 0 && i->first.y >= 0 && i->first.x < (long)width_ && i->first.y < (long)height_) {
 			config& label = res.add_child("label");
 			label["text"] = i->second;
 			i->first.write(label);
