@@ -1,4 +1,4 @@
-/* $Id: dummy_video.cpp,v 1.2 2004/07/19 18:31:32 gruikya Exp $ */
+/* $Id: dummy_video.cpp 12009 2006-06-10 18:59:00Z torangan $ */
 /*
    Copyright (C) 2004 by Philippe Plantier <ayin@anathas.org>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -18,11 +18,11 @@ surface CVideo::getSurface()
 	return NULL;
 }
 
-void update_rect(const SDL_Rect& rect)
+void update_rect(const SDL_Rect&)
 {
 }
 
-surface display_format_alpha(surface surf)
+surface display_format_alpha(surface)
 {
 	return NULL;
 }
