@@ -1,4 +1,4 @@
-/* $Id: video.cpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: video.cpp 12503 2006-07-11 20:57:03Z noyga $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -74,7 +74,7 @@ unsigned int get_flags(unsigned int flags)
 {
 	//SDL under Windows doesn't seem to like hardware surfaces for
 	//some reason.
-#if !(defined(_WIN32) || defined(__APPLE__))
+#if !(defined(_WIN32) || defined(__APPLE__) || defined(__AMIGAOS4__))
 		flags |= SDL_HWSURFACE;
 #endif
 	if((flags&SDL_FULLSCREEN) == 0)
