@@ -1,4 +1,4 @@
-/* $Id: video.hpp 7396 2005-07-02 21:37:20Z ott $ */
+/* $Id: video.hpp 11647 2006-05-26 01:03:08Z rusty $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -27,7 +27,7 @@ SDL_Rect screen_area();
 
 bool non_interactive();
 
-
+//which areas of the screen will be updated when the buffer is flipped?
 void update_rect(size_t x, size_t y, size_t w, size_t h);
 void update_rect(const SDL_Rect& rect);
 void update_whole_screen();
@@ -77,7 +77,7 @@ class CVideo {
 	int getBpp();
 
 	void make_fake();
-	bool faked() { return fake_screen; }
+	bool faked() const { return fake_screen; }
 
 	//functions to set and clear 'help strings'. A 'help string' is like a tooltip, but it appears
 	//at the bottom of the screen, so as to not be intrusive. Setting a help string sets what
